feast.infra.materialization package
===================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   feast.infra.materialization.lambda

Submodules
----------

feast.infra.materialization.batch\_materialization\_engine module
-----------------------------------------------------------------

.. automodule:: feast.infra.materialization.batch_materialization_engine
   :members:
   :undoc-members:
   :show-inheritance:

feast.infra.materialization.local\_engine module
------------------------------------------------

.. automodule:: feast.infra.materialization.local_engine
   :members:
   :undoc-members:
   :show-inheritance:

feast.infra.materialization.snowflake\_engine module
----------------------------------------------------

.. automodule:: feast.infra.materialization.snowflake_engine
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: feast.infra.materialization
   :members:
   :undoc-members:
   :show-inheritance:
